@@ -33,7 +33,7 @@
 #'     \item{`delete(path, query, body, disk, stream, ...)`}{
 #'       Define a DELETE request
 #'     }
-#'     \item{`head(path, disk, stream, ...)`}{
+#'     \item{`head(path, ...)`}{
 #'       Define a HEAD request
 #'     }
 #'     \item{`method()`}{
@@ -47,7 +47,7 @@
 #' @format NULL
 #' @usage NULL
 #'
-#' @examples
+#' @examples \dontrun{
 #' x <- HttpRequest$new(url = "https://httpbin.org/get")
 #' ## note here how the HTTP method is shown on the first line to the right
 #' x$get()
@@ -70,6 +70,7 @@
 #'     `Content-Type` = "application/json"
 #'   )
 #' )
+#' }
 HttpRequest <- R6::R6Class(
   'HttpRequest',
   public = list(
@@ -79,6 +80,7 @@ HttpRequest <- R6::R6Class(
     auth = list(),
     headers = list(),
     handle = NULL,
+    progress = NULL,
     payload = NULL,
 
     print = function(x, ...) {
@@ -103,20 +105,40 @@ HttpRequest <- R6::R6Class(
         cat(sprintf("    %s: %s", names(self$headers)[i],
                     self$headers[[i]]), sep = "\n")
       }
+      cat(paste0("  progress: ", !is.null(self$progress)), sep = "\n")
       invisible(self)
     },
 
-    initialize = function(url, opts, proxies, auth, headers, handle) {
+    initialize = function(url, opts, proxies, auth, headers, handle, progress) {
       if (!missing(url)) self$url <- url
+
+      # curl options: check for set_opts first
+      if (!is.null(crul_opts$opts)) self$opts <- crul_opts$opts
       if (!missing(opts)) self$opts <- opts
+
+      # proxy: check for set_proxy first
+      if (!is.null(crul_opts$proxies)) self$proxies <- crul_opts$proxies
       if (!missing(proxies)) {
         if (!inherits(proxies, "proxy")) {
           stop("proxies input must be of class proxy", call. = FALSE)
         }
         self$proxies <- proxies
       }
+
+      # auth: check for set_auth first
+      if (!is.null(crul_opts$auth)) self$auth <- crul_opts$auth
       if (!missing(auth)) self$auth <- auth
+
+      # progress
+      if (!missing(progress)) {
+        assert(progress, "request")
+        self$progress <- progress$options
+      }
+
+      # headers: check for set_headers first
+      if (!is.null(crul_opts$headers)) self$headers <- crul_opts$headers
       if (!missing(headers)) self$headers <- headers
+      
       if (!missing(handle)) self$handle <- handle
       if (is.null(self$url) && is.null(self$handle)) {
         stop("need one of url or handle", call. = FALSE)
@@ -130,18 +152,12 @@ HttpRequest <- R6::R6Class(
       rr <- list(
         url = url,
         method = "get",
-        options = list(
-          httpget = TRUE,
-          useragent = make_ua()
-        ),
-        headers = list(
-          `User-Agent` = make_ua(),
-          `Accept-Encoding` = 'gzip, deflate'
-        )
+        options = ccp(list(httpget = TRUE, cainfo = find_cert_bundle())),
+        headers = def_head()
       )
       rr$headers <- norm_headers(rr$headers, self$headers)
       rr$options <- utils::modifyList(
-        rr$options, c(self$opts, self$proxies, self$auth, ...))
+        rr$options, c(self$opts, self$proxies, self$auth, self$progress, ...))
       rr$disk <- disk
       rr$stream <- stream
       self$payload <- rr
@@ -196,23 +212,18 @@ HttpRequest <- R6::R6Class(
       return(self)
     },
 
-    head = function(path = NULL, disk = NULL, stream = NULL, ...) {
+    head = function(path = NULL, ...) {
       curl_opts_check(...)
       url <- make_url_async(self$url, self$handle, path, NULL)
       opts <- list(customrequest = "HEAD", nobody = TRUE)
       rr <- list(
         url = url,
         method = "head",
-        options = c(
-          opts,
-          useragent = make_ua()
-        ),
+        options = ccp(c(opts, cainfo = find_cert_bundle())),
         headers = self$headers
       )
       rr$options <- utils::modifyList(rr$options,
                                       c(self$opts, self$proxies, ...))
-      rr$disk <- disk
-      rr$stream <- stream
       self$payload <- rr
       return(self)
     },
