@@ -21,7 +21,11 @@ add_query <- function(x, url) {
   if (length(x)) {
     quer <- list()
     for (i in seq_along(x)) {
-      quer[[i]] <- paste(names(x)[i], urltools::url_encode(x[[i]]), sep = "=")
+      if (!inherits(x[[i]], "AsIs")) {
+        x[[i]] <- curl::curl_escape(x[[i]])
+      }
+      quer[[i]] <- paste(curl::curl_escape(names(x)[i]), 
+        x[[i]], sep = "=")
     }
     parms <- paste0(quer, collapse = "&")
     paste0(url, "?", parms)
