@@ -3,7 +3,7 @@ context("request: delete")
 test_that("delete request works", {
   skip_on_cran()
 
-  cli <- HttpClient$new(url = "https://httpbin.org")
+  cli <- HttpClient$new(url = hb())
   aa <- cli$delete("delete")
 
   expect_is(aa, "HttpResponse")
@@ -21,7 +21,7 @@ test_that("delete request works", {
 test_that("delete request with body", {
   skip_on_cran()
 
-  cli <- HttpClient$new(url = "https://httpbin.org")
+  cli <- HttpClient$new(url = hb())
   aa <- cli$delete("delete", body = list(hello = "world"))
 
   expect_is(aa, "HttpResponse")
@@ -30,7 +30,7 @@ test_that("delete request with body", {
   expect_is(aa$method, "character")
   expect_equal(aa$method, "delete")
   expect_is(aa$parse, "function")
-  expect_is(aa$parse(), "character")
+  expect_is(aa$parse("UTF-8"), "character")
   expect_true(aa$success())
 
   expect_named(aa$request$fields, "hello")
