@@ -3,7 +3,7 @@ context("headers")
 test_that("headers work - just default headers", {
   skip_on_cran()
 
-  cli <- HttpClient$new(url = "https://httpbin.org")
+  cli <- HttpClient$new(url = hb())
   aa <- cli$get('get')
 
   expect_is(aa, "HttpResponse")
@@ -14,7 +14,7 @@ test_that("headers work - user headers passed", {
   skip_on_cran()
 
   cli <- HttpClient$new(
-    url = "https://httpbin.org",
+    url = hb(),
     headers = list(hello = "world")
   )
   bb <- cli$get('get')
