@@ -3,7 +3,7 @@ context("request: patch")
 test_that("patch request works", {
   skip_on_cran()
 
-  cli <- HttpClient$new(url = "https://httpbin.org")
+  cli <- HttpClient$new(url = hb())
   aa <- cli$patch("patch")
 
   expect_is(aa, "HttpResponse")
@@ -21,7 +21,7 @@ test_that("patch request works", {
 test_that("patch request with body", {
   skip_on_cran()
 
-  cli <- HttpClient$new(url = "https://httpbin.org")
+  cli <- HttpClient$new(url = hb())
   aa <- cli$patch("patch", body = list(hello = "world"))
 
   expect_is(aa, "HttpResponse")
